@@ -1,17 +1,19 @@
 #! /usr/bin/perl
 
-# $Id: uvt-email-template.pl 39328 2013-05-02 14:44:14Z wsl $
+# $Id: uvt-email-template.pl 39332 2013-05-03 07:57:53Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/uvt-email-template/bin/uvt-email-template.pl $
 
 use strict;
 use warnings FATAL => 'all';
 use utf8;
 
+our $pkgdatadir //= our $datadir ? "$datadir/$PACKAGE" : 'share';
+
 BEGIN { unshift @INC, qw(lib) }
 
 use UvT::Email::Template;
 
-my $e = new UvT::Email::Template(htmltemplate => 'html.xsl');
+my $e = new UvT::Email::Template(htmltemplate => "$pkgdatadir/html.xsl");
 
 print $e->format($ARGV[0], Subject => 'testje');
 
